## 介绍

这是一个测试上传到pypi的mcp服务器demo。

## 使用方法
 uvx  mcp-pypi-jhl-weather-server
 返回  Hello from mcp-pypi-jhl-weather-server!  
## MCP 配置

### uvx
  
```json

{

    "mcpServers": {

        "duckduckgo": {

            "command": "uvx",

            "args": [

                 "mcp-pypi-jhl-weather-server"

            ]

        }

     }

}

